# KMUHelper

Der KMUHelper ist, wie der Name schon sagt, ein Helfer für KMU, hauptsächlich für Schweizer, da der Hauptgrund für
die Entwicklung dieser Djangoapp die neue schweizer QR-Rechnung ist.

Diverse Infos über den KMUHelper gibt's [hier](https://rafaelurben.github.io/django-kmuhelper/).

Bei Fragen oder Probleme bitte unbedingt bei [mir](https://rafaelurben.github.io/diverses/rafaelurben/#kontakt) melden oder ein Issue eröffnen!
